/***************************************************************************
 *   Copyright (C) 2005 by Krzysztof Zawadyl                               *
 *   k.zawadyl@gmail.com                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef _METAMONITOR_H_
#define _METAMONITOR_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <qpixmap.h>

#include <ksystemtray.h>

class QTimer;
class Message;
class Popup;
class FileMonitor;
class MessageTable;
class DCOPListener;

/**
 * @brief Application Main Window
 * @author Krzysztof Zawadyl
 */
class MetaMonitor : public KSystemTray
{
Q_OBJECT
	public:
	
	MetaMonitor();
	
	virtual ~MetaMonitor();
	
public:
	enum LogDaemonType { NoLog = 0,	MetaLog = 1, SysLog = 2	};
	
	int					updateInterval() { return mUpdateInterval; };
	int					popupsLifetime() { return mPopupsLifetime; };
	QString				getLogFile() { return logFile; };
	bool				getDrawShadow() { return drawShadow; };
	LogDaemonType		useDefaultRegExp() { return defaultRegExp; };
	QString				getCustomRegExp() { return customRegExp; };
	bool				getGroupMessages() { return groupMessages; };
	bool				getPausePopups() { return pausePopups; };
	
public slots:
	void 				about();
	void 				update();
	void 				configure();
	void 				messageTable();
	void				switchPausePopups();
	void				writeConfig();
	void 				addMessage(QString,QString);
	
protected:
	void 				mousePressEvent( QMouseEvent* ev );
	FileMonitor *		fileMonitor;
	
private:
	QPixmap 			mIcon;
	QTimer *			mTimer;
	Popup * 			pop;
	MessageTable *		messageViewer;
	QPtrList<Message>	messagesList;
	int					mUpdateInterval;
	int					mPopupsLifetime;
	QString				logFile;
	QString				customRegExp;
	LogDaemonType		defaultRegExp;
	bool				drawShadow;
	bool				groupMessages;
	bool				pausePopups;
	int					pauseId;
	DCOPListener *		listener;
};

#endif // _METAMONITOR_H_
