/***************************************************************************
 *   Copyright (C) 2005 by Krzysztof Zawadyl                               *
 *   k.zawadyl@gmail.com                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef POPUP_H
#define POPUP_H

#include "metamonitor.h"
#include "popupmessage.h"

#include <kpassivepopup.h>

class QPaintEvent;
class QColor;
class QVBox;
class KActiveLabel;
class Message;

/**
 * @class Popup
 * @brief Generates a KPassivePopup with rounded corners
 * 
 * @author Krzysztof Zawadyl
 */
class Popup : public KPassivePopup
{
Q_OBJECT

public:
	Popup( MetaMonitor *parent );
	~Popup();
	
	bool  			pendingMessages() { return !messageQueue.isEmpty(); };
	void  			addToMessageQueue( Message *m );
	void  			showMessages();
	static Popup * 	message( MetaMonitor *parent, Message *m );
	int				lifeTime() { return mm->popupsLifetime(); };
	
public slots:
	void 			removeMessage(QPoint pos);
	void			removeMessage(PopupMessage *pm);
	void			removeOldMessages();
	
public:
	QPixmap 		mIcon;
	QPixmap 		sshIcon;
	QPixmap 		kernelIcon;

protected:
	void 			paintEvent( QPaintEvent *e );
	void 			setView();
	
private:
	void 			init();
	
	QBoxLayout *	topLayout;
	QTimer *		hideTimer;
	QColor			bgColor;
	MetaMonitor *	mm;
	QLabel *    	ttlIcon;
	KActiveLabel *  msg;
	QLabel *  		ttl;
	QPtrList<PopupMessage>	messageQueue;
};

#endif
