/***************************************************************************
 *   Copyright (C) 2005 by Krzysztof Zawadyl                               *
 *   k.zawadyl@gmail.com                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "metamonitor.h"
#include "popup.h"
#include "message.h"
#include "popupmessage.h"

#include <qlabel.h>
#include <qvbox.h>
#include <qtooltip.h>
#include <qtimer.h>
#include <qpixmap.h>

#include <kactivelabel.h>
#include <kdialog.h>
#include <klocale.h>

/**
 * @brief Constructor
 * 
 * @param m Messages pointer
 * @param parent Pointer to the parent widget
 * @param name PopupMessage's name
 */
PopupMessage::PopupMessage(Message *m, Popup *parent, const char *name)
 : QVBox(parent, name)
{
	expired = false;
	timerStarted = false;
	p = parent;
	
	setSpacing( KDialog::spacingHint() );
	setMaximumWidth( 400 );
	
	QHBox *hb=0;
	
	QPixmap icon;
	if( m->getFrom() == "kernel" )
		icon = parent->kernelIcon;
	else
		if( m->getFrom() == "sshd" || m->getFrom().contains( "pam_unix" ) )
			icon = parent->sshIcon;
	else
		icon = parent->mIcon;
	
	hb = new QHBox( this );
	hb->setMargin( 0 );
	hb->setSpacing( KDialog::spacingHint() );
	ttlIcon = new QLabel( hb, "title_icon" );
	ttlIcon->setPixmap( icon );
	ttlIcon->setAlignment( AlignLeft );
	
	if ( !m->getFrom().isEmpty() ) 
	{
		ttl = new QLabel( i18n( "Message from %1:" ).arg( m->getFrom() ), hb ? hb : this, "title_label" );
		QFont fnt = ttl->font();
		fnt.setBold( true );
		ttl->setFont( fnt );
		ttl->setAlignment( Qt::AlignHCenter );
		if ( hb )
			hb->setStretchFactor( ttl, 10 ); // enforce centering
	}
	
	if ( !m->getText().isEmpty() ) 
	{
		msg = new KActiveLabel( m->getText(), this, "msg_label" );
		msg->setPalette( QToolTip::palette() );
		msg->setAlignment( AlignLeft );
	}

	hideTimer = new QTimer( this, "hide_timer" );
	connect( hideTimer, SIGNAL( timeout() ), SLOT( timerDone() ) );
}

/**
 * @brief Destructor
 */
PopupMessage::~PopupMessage()
{
	if( hideTimer )
		delete hideTimer;
}

/**
 * @brief Start's timer
 * 
 * Starts hide timer. If the timer is already started it does nothing.
 */
void PopupMessage::startTimer()
{
	if( timerStarted == true )
		return;
	
	timerStarted = true;
	if( p->lifeTime() )
		hideTimer->start( p->lifeTime(), TRUE );
}

/**
 * @brief Timer timeout reaction
 * 
 * Hides the PopupMessage's Widget and marks itself as expired. Then it tells parent
 * to show messages once again.
 */
void PopupMessage::timerDone()
{
	hide();
	expired = true;
	p->showMessages();
}
#include "popupmessage.moc"
